package net.knarcraft.knarlib.formatting;

import org.jetbrains.annotations.NotNull;

/**
 * An enum containing all translatable time units
 *
 * <p>These time units must have a translatable message if you want to use the time formatter. Register one value with
 * the translator's "registerMessageCategory" method!</p>
 */
@SuppressWarnings("unused")
public enum TranslatableTimeUnit implements TranslatableMessage {

    /**
     * The format for displaying the duration of something
     */
    DURATION_FORMAT,

    /**
     * The text to display for 0 seconds
     */
    UNIT_NOW,

    /**
     * The text to display for 1 second
     */
    UNIT_SECOND,

    /**
     * The text to display for a number of seconds
     */
    UNIT_SECONDS,

    /**
     * The text to display for 1 minute
     */
    UNIT_MINUTE,

    /**
     * The text to display for a number of minutes
     */
    UNIT_MINUTES,

    /**
     * The text to display for 1 hour
     */
    UNIT_HOUR,

    /**
     * The text to display for a number of hours
     */
    UNIT_HOURS,

    /**
     * The text to display for 1 day
     */
    UNIT_DAY,

    /**
     * The text to display for a number of days
     */
    UNIT_DAYS,

    /**
     * The text to display for 1 week
     */
    UNIT_WEEK,

    /**
     * The text to display for a number of weeks
     */
    UNIT_WEEKS,

    /**
     * The text to display for 1 month
     */
    UNIT_MONTH,

    /**
     * The text to display for a number of months
     */
    UNIT_MONTHS,

    /**
     * The text to display for 1 year
     */
    UNIT_YEAR,

    /**
     * The text to display for a number of years
     */
    UNIT_YEARS,

    /**
     * The text to display for 1 decade
     */
    UNIT_DECADE,

    /**
     * The text to display for a number of decades
     */
    UNIT_DECADES,
    ;

    @Override
    public @NotNull TranslatableMessage[] getAllMessages() {
        return TranslatableTimeUnit.values();
    }

}
